package Acme::MetaSyntactic::trigan;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.000';
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::trigan - The I<The Trigan Empire> theme

=head1 DESCRIPTION

Characters from the British comic I<The Trigan Empire>, written
mainly by Mike Butterworth with beautiful artwork by I<Don Lawrence>.
The comic ran from 1965 till 1982.

Learn all about it on L<http://www.trigan.com/>.

=head1 CONTRIBUTOR

Abigail

=head1 CHANGES

=over 4

=item *

2012-05-07

Received its own version number in Acme-MetaSyntactic-Themes version 1.000.

=item *

2006-03-06

Introduced in Acme-MetaSyntactic version 0.64.

=item *

2005-10-27

Submitted by Abigail.

=back

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Trigo Brag Klud Peric Janno Keren Roffa Salvia Kassar Ursa Argo Rilla Nikka
